#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-8diwAOUTQH5AMaxxcRVkPR
key:                  pantry-0.8.3-8diwAOUTQH5AMaxxcRVkPR
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  8486e5daf9abd38766d6066ce35aee22
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-8diwAOUTQH5AMaxxcRVkPR
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj
    ansi-terminal-1.1-BNAdu1zLoFX9s2bsz5V7NA base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.4-2p5zQKrrq1cDeNs9zoSWZe
    casa-types-0.0.3-9YpVB4Yujdi1jYyBNtS9Ly
    conduit-1.3.6.1-7MjmOtU85HaB8wB7sCyBPV
    conduit-extra-1.3.8-J1pruM4XzBY6KaacrfmX7n containers-0.6.7
    crypton-1.0.4-5dxKfIBRa6R2YE55iyrOUy
    crypton-conduit-0.2.3-IdgxzCr2qtNBIOUBCwr5Wf
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.9-ETR6ZYppKlZHRmLOB2x6JA
    generic-deriving-1.14.7-EdpMS6VUjSWAYwhkxCiLC8
    hackage-security-0.6.3.2-F8YCghsneegL2pcd4QtNxr
    hpack-0.38.0-1xOJOndjP0UHDjxUoVv7lq
    http-client-0.7.19-LN5QT3bQF9y5GsNu19wbhO
    http-client-tls-0.3.6.4-BpM0XRSvwZ99JZv1J5vtXV
    http-conduit-2.3.9.1-9MREEIGDTJE2iYXOHTEmcN
    http-download-0.2.1.0-DZfCJsyXuiPKFzdOUUhATi
    http-types-0.12.4-57DQrkzau5HINFiGCpRQOB
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-Fs1V3yFgC4iGyoDpGJIE7J
    path-0.9.6-FPswj21yURv88mENZJRf3U
    path-io-1.8.2-6795MZR1SVAL4C9h5F8gBE
    persistent-2.14.6.0-8WXih0Nu8qx1p1lVDUgiYw
    persistent-sqlite-2.13.2.0-AdQRzPIPCiG7S5DHOYAAMj
    primitive-0.9.1.0-5zbRYrfoFPr4oGDF3kIYIh
    resourcet-1.3.0-45p4IDaKvNI1WME3k22VJi
    rio-0.1.24.0-6fEeJnSmO8M9mijhGz0veX
    rio-orphans-0.1.2.0-Kocn44Ryrsv5QEcDPZJvGS
    rio-prettyprint-0.1.8.0-AYuAYEH7JW32qhAbDeZXvB
    tar-conduit-0.4.1-1dDZcPae3InCtcU30VlFia text-2.0.2
    text-metrics-0.3.3-vzJAhxAqTO1RFrncdf4Rf time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-9XJmvTTI62BHh5oKVcMeBg
    unliftio-0.2.25.1-JwtBWAs5WUC67yAeM1UF4A
    unordered-containers-0.2.21-LjCRrPGX8vKp2UxAfh6M2
    vector-0.13.2.0-HJSwbt845rQ2AOZrNm5BDk
    yaml-0.11.11.2-7UoXYkKWr4r4oNCJDlnyxG
    zip-archive-0.4.3.2-GF01YJ4Y7mT94q7blBMXAe

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

